@@ -194,6 +194,7 @@ def nx_from_queryset(
     node_attribute_fields_list=None,
     edge_attribute_fields_list=None,
     date_strf=None,
+    digraph=False,
 ):
     """
     Provided a queryset of nodes or edges, returns a NetworkX graph
@@ -202,13 +203,18 @@ def nx_from_queryset(
     graph_attributes_dict: A dictionary of attributes to add to the graph itself
     node_attribute_fields_list: a list of strings of field names to be added to nodes
     edge_attribute_fields_list: a list of strings of field names to be added to edges
+    date_strf: if any provided fields are date-like, how should they be formatted?
+    digraph: bool to determine whether to output a directed or undirected graph
     """
     _NodeModel, _EdgeModel, queryset_type = get_queryset_characteristics(queryset)
 
     if graph_attributes_dict is None:
         graph_attributes_dict = {}
 
-    graph = nx.Graph(**graph_attributes_dict)
+    if not digraph:
+        graph = nx.Graph(**graph_attributes_dict)
+    else:
+        graph = nx.DiGraph(**graph_attributes_dict)
 
     if queryset_type == "nodes_queryset":
         nodes_queryset = queryset
